@@ -4,18 +4,7 @@ import subprocess
 import sys
 from functools import wraps
 from subprocess import PIPE, CalledProcessError
-from typing import (
-    Any,
-    Callable,
-    Iterator,
-    Mapping,
-    Optional,
-    Pattern,
-    Sequence,
-    Type,
-    TypeVar,
-    cast,
-)
+from typing import Any, Callable, Iterator, Optional, Sequence, Type, TypeVar, cast
 
 import analytics
 import click
@@ -23,7 +12,13 @@ from sentry_sdk.api import configure_scope
 from sentry_sdk.hub import init as sentry_init
 
 from .commands import GlobalOptions
-from .errors import CliError, FailedSubprocessError, SuppressedError
+from .errors import (
+    CliError,
+    ErrorPatterns,
+    FailedSubprocessError,
+    SuppressedError,
+    raise_if_match,
+)
 from .helpers import segment
 from .helpers.config import Config
 from .helpers.keywords_to_options import Argument, keywords_to_options
@@ -36,6 +31,7 @@ from .helpers.sentry import set_scope_context_os, set_scope_tag_org, set_scope_u
 
 
 F = TypeVar("F", bound=Callable[..., Any])
+ProdMode = os.getenv("SENTRY_ENVIRONMENT") != "development"
 
 
 def run_subprocess(
@@ -66,10 +62,7 @@ def run_subprocess(
 
 
 def intercept_errors(
-    patterns: Mapping[Pattern[str], Type[Exception]] = {},
-    *,
-    quiet: bool = False,
-    suppress: bool = False,
+    patterns: ErrorPatterns = {}, *, quiet: bool = False, suppress: bool = False,
 ) -> Callable[[F], F]:
     def decorate(fn: F) -> F:
         @wraps(fn)
@@ -80,15 +73,7 @@ def intercept_errors(
                 return fn(*args, **kwargs)
             except CalledProcessError as err:
                 message = err.stderr
-                if error := next(
-                    (
-                        error
-                        for pattern, error in patterns.items()
-                        if pattern.search(message)
-                    ),
-                    None,
-                ):
-                    raise error
+                raise_if_match(patterns, message)
                 if not (quiet or quiet_):
                     sys.stderr.write(message)
                 if suppress or suppress_:
@@ -132,7 +117,7 @@ def require_login(fn: F) -> F:
 
 
 def setup_segment(**kwargs: Any) -> Callable[[F], F]:
-    analytics.default_client = analytics.client.Client(**kwargs)
+    analytics.default_client = analytics.client.Client(send=ProdMode, **kwargs)
 
     def decorator(fn: F) -> F:
         @click.pass_context
