@@ -1,3 +1,4 @@
+import os
 from typing import Dict, NamedTuple, Optional, TypedDict
 
 import validators
@@ -14,6 +15,7 @@ class Profile(NamedTuple):
 
 
 class OrgParams(TypedDict, total=False):
+    resource_env_var: Optional[str]
     ssh_user: str
     domain: str
     aws_saml_url: str
@@ -24,6 +26,7 @@ class OrgParams(TypedDict, total=False):
 
 PARAMS: Dict[str, OrgParams] = {
     "launch-darkly": {
+        "resource_env_var": "ENVIRONMENT",
         "ssh_user": "ubuntu",
         "domain": "launchdarkly.com",
         "aws_saml_url": "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272",
@@ -63,6 +66,7 @@ PARAMS: Dict[str, OrgParams] = {
         },
     },
     "sym": {
+        "resource_env_var": "ENVIRONMENT",
         "ssh_user": "ssm-user",
         "domain": "symops.io",
         "aws_okta_params": {},
@@ -115,6 +119,15 @@ def get_ssh_user() -> str:
     return get_org_params()["ssh_user"]
 
 
+def get_resource_env_var() -> Optional[str]:
+    try:
+        env_var = get_org_params()["resource_env_var"]
+        default = os.getenv(env_var) if env_var else None
+    except KeyError:
+        default = None
+    return Config.instance().get("default_resource", default)
+
+
 def get_profile(resource: str) -> Profile:
     return get_profiles()[resource]
 
