@@ -5,17 +5,19 @@ from textwrap import dedent
 from typing import Sequence
 
 from ..decorators import intercept_errors, run_subprocess
-from ..errors import WrappedSubprocessError
+from ..errors import TargetNotConnected, WrappedSubprocessError
 from ..helpers.boto import send_ssh_key
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.params import get_ssh_user
 
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
+TargetNotConnectedPattern = re.compile("TargetNotConnected")
 
 SSHConfig = SymConfigFile("ssh/config")
 SSHKey = SymConfigFile("ssh/key")
 
 
+@intercept_errors()
 @run_subprocess
 def gen_ssh_key(dest: SymConfigFile):
     dest.path.parent.mkdir(parents=True, exist_ok=True)
@@ -64,6 +66,7 @@ def start_ssh_session(
         Config.touch_instance(instance)
 
 
+@intercept_errors({TargetNotConnectedPattern: TargetNotConnected}, suppress=True)
 def ensure_ssh_key(client, instance: str, port: int):
     instance_config = Config.get_instance(instance)
 
