@@ -3,15 +3,15 @@ from pathlib import Path
 from typing import Final, Iterator, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
-from ..errors import UnavailableRoleError
+from ..errors import ResourceNotSetup, UnavailableResourceError
 from ..helpers.config import SymConfigFile
-from ..helpers.constants import AwsOktaNoRoles
+from ..helpers.constants import AwsOktaNoRoles, AwsOktaNotSetup
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument
 from ..helpers.params import get_aws_okta_params
 from . import SAMLClient
 
-ErrorPatterns = {AwsOktaNoRoles: UnavailableRoleError}
+ErrorPatterns = {AwsOktaNoRoles: UnavailableResourceError, AwsOktaNotSetup: ResourceNotSetup}
 
 class AwsOkta(SAMLClient):
     __slots__ = ["aws_okta_cfg", "resource", "debug"]
