@@ -4,7 +4,7 @@ from pathlib import Path
 from typing import Final, Iterator, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
-from ..errors import UnavailableRoleError
+from ..errors import UnavailableResourceError
 from ..helpers.config import SymConfigFile
 from ..helpers.constants import Saml2AwsNoRoles
 from ..helpers.contexts import push_env
@@ -12,7 +12,7 @@ from ..helpers.keywords_to_options import Argument, Options, keywords_to_options
 from ..helpers.params import get_saml2aws_params
 from . import SAMLClient
 
-ErrorPatterns = {Saml2AwsNoRoles: UnavailableRoleError}
+ErrorPatterns = {Saml2AwsNoRoles: UnavailableResourceError}
 
 
 class Saml2Aws(SAMLClient):
