@@ -1,4 +1,6 @@
+from .commands import import_all
 from .commands.sym import sym
 from .helpers.init import sym_init
 
+import_all()
 sym_init()
