@@ -17,9 +17,9 @@ def org(sandbox: Sandbox, uuid: UUID) -> str:
 
 def test_get_org_with_xdg_config_home(sandbox: Sandbox, org: str) -> None:
     with push_env("XDG_CONFIG_HOME", str(sandbox.path / ".config")):
-        assert Config().get_org() == org
+        assert Config()["org"] == org
 
 
 def test_get_org_without_xdg_config_home(sandbox: Sandbox, org: str) -> None:
     with push_env("HOME", str(sandbox.path)):
-        assert Config().get_org() == org
+        assert Config()["org"] == org
